@@ -1,9 +1,12 @@
 import pika
 import uuid
+import requests
 
 
 class EventProducer(object):
-    def __init__(self, username, password, host, port):
+    def __init__(self, username, password, host, port, service_name, logger):
+        self.service_name = service_name
+        self.logger = logger
         self.credentials = pika.PlainCredentials(username, password)
         self.connection = pika.BlockingConnection(pika.ConnectionParameters(host=host,
                                                                             port=port,
@@ -37,4 +40,14 @@ class EventProducer(object):
         )
         while self.response is None:
             self.connection.process_data_events()
-        return self.response
\ No newline at end of file
+
+        if self.logger is not None:
+            params = {"correlation_id": self.corr_id,
+                      "queue_name": queue_name,
+                      "service_name": self.service_name,
+                      "payload": payload,
+                      "response": self.response.decode("utf-8")
+                      }
+            requests.post(self.logger, json=params)
+
+        return self.response
