@@ -1,9 +1,13 @@
 import pika
+import requests
 
 
 class EventReceiver(object):
-    def __init__(self, username, password, host, port, queue_name, service):
+    def __init__(self, username, password, host, port, queue_name, service, service_name, logger):
         self.service_worker = service
+        self.service_name = service_name
+        self.queue_name = queue_name
+        self.logger = logger
 
         credentials = pika.PlainCredentials(username, password)
         connection = pika.BlockingConnection(pika.ConnectionParameters(host=host,
@@ -29,4 +33,14 @@ class EventReceiver(object):
                          body=response)
         ch.basic_ack(delivery_tag=method.delivery_tag)
 
+        if self.logger is not None:
+            params = {"correlation_id": props.correlation_id,
+                      "queue_name": self.queue_name,
+                      "service_name": self.service_name,
+                      "task_type": task_type,
+                      "payload": body.decode("utf-8"),
+                      "response": response
+                      }
+            requests.post(self.logger, json=params)
+
         print('Processed request:', task_type)
